@@ -122,13 +122,15 @@ sub _init {
         if (!$retval and @errors == 0) {
             push @errors, "unknown error processing arguments!";
         }
-        # we want to allow unknown option if the user puts them in, we just
-        # didn't help complete it
-        @errors = grep { $_ !~ /^Unknown option:/ } @errors;
+        if ($ENV{COMP_LINE}) {
+            # we want to allow unknown option if the user puts them in, we just
+            # didn't help complete it
+            @errors = grep { $_ !~ /^Unknown option:/ } @errors;
+        }
     };
 
     if (@ARGV) {
-        if ($self->options->completion_handler('<>')) {
+        if ($self->options->has_option('<>')) {
             my $a = $values{'<>'} ||= [];
             push @$a, @ARGV;
         }
@@ -488,7 +490,7 @@ Getopt::Complete::Args - a set of option/value pairs
 
 =head1 VERSION
 
-This document describes Getopt::Complete::Args 0.20.
+This document describes Getopt::Complete::Args 0.24.
 
 =head1 SYNOPSIS
 
